@@ -1,11 +1,11 @@
 ##############################################################################
 # Net::Twitter - Perl OO interface to www.twitter.com
-# v2.04
+# v2.05
 # Copyright (c) 2009 Chris Thompson
 ##############################################################################
 
 package Net::Twitter;
-$VERSION = "2.04";
+$VERSION = "2.05";
 use 5.005;
 use strict;
 
@@ -42,7 +42,7 @@ sub new {
     $conf{clientver}  = $Net::Twitter::VERSION        unless defined $conf{clientver};
     $conf{clienturl}  = "http://www.net-twitter.info" unless defined $conf{clienturl};
 
-    $conf{source}     = 'twitterpm'
+    $conf{source} = 'twitterpm'
       unless defined $conf{source};    ### Make it say "From Net:Twitter"
 
     ### Allow specifying a class other than LWP::UA
@@ -254,266 +254,270 @@ sub search {
 ### Load method data into %apicalls at runtime.
 
 BEGIN {
-    my %apicalls = (
-        "public_timeline" => {
-            "blankargs" => 0,
-            "post"      => 0,
-            "uri"       => "/statuses/public_timeline",
-            "args"      => {},
-        },
-        "friends_timeline" => {
-            "blankargs" => 1,
-            "post"      => 0,
-            "uri"       => "/statuses/friends_timeline",
-            "args"      => {
-                "since"    => 0,
-                "since_id" => 0,
-                "count"    => 0,
-                "page"     => 0,
-            },
-        },
-        "user_timeline" => {
-            "blankargs" => 1,
-            "post"      => 0,
-            "uri"       => "/statuses/user_timeline/ID",
-            "args"      => {
-                "id"       => 0,
-                "since"    => 0,
-                "since_id" => 0,
-                "count"    => 0,
-                "page"     => 0,
-            },
-        },
-        "show_status" => {
-            "blankargs" => 0,
-            "post"      => 0,
-            "uri"       => "/statuses/show/ID",
-            "args"      => { "id" => 1, },
-        },
-        "update" => {
-            "blankargs" => 0,
-            "post"      => 1,
-            "uri"       => "/statuses/update",
-            "args"      => {
-                "status"                => 1,
-                "in_reply_to_status_id" => 0,
-                "source"                => 0,
-            },
-        },
-        "replies" => {
-            "blankargs" => 1,
-            "post"      => 0,
-            "uri"       => "/statuses/replies",
-            "args"      => {
-                "page"     => 0,
-                "since"    => 0,
-                "since_id" => 0,
-            },
-        },
-        "destroy_status" => {
-            "blankargs" => 0,
-            "post"      => 1,
-            "uri"       => "/statuses/destroy/ID",
-            "args"      => { "id" => 1, },
-        },
-        "friends" => {
-            "blankargs" => 1,
-            "post"      => 0,
-            "uri"       => "/statuses/friends/ID",
-            "args"      => {
-                "id"    => 0,
-                "page"  => 0,
-                "since" => 0,
-            },
-        },
-        "followers" => {
-            "blankargs" => 1,
-            "post"      => 0,
-            "uri"       => "/statuses/followers",
-            "args"      => {
-                "id"   => 0,
-                "page" => 0,
-            },
-        },
-        "show_user" => {
-            "blankargs" => 0,
-            "post"      => 0,
-            "uri"       => "/users/show/ID",
-            "args"      => {
-                "id"    => 1,
-                "email" => 1,
-            },
-        },
-        "direct_messages" => {
-            "blankargs" => 1,
-            "post"      => 0,
-            "uri"       => "/direct_messages",
-            "args"      => {
-                "since"    => 0,
-                "since_id" => 0,
-                "page"     => 0,
-            },
-        },
-        "sent_direct_messages" => {
-            "blankargs" => 1,
-            "post"      => 0,
-            "uri"       => "/direct_messages/sent",
-            "args"      => {
-                "since"    => 0,
-                "since_id" => 0,
-                "page"     => 0,
-            },
-        },
-        "new_direct_message" => {
-            "blankargs" => 0,
-            "post"      => 1,
-            "uri"       => "/direct_messages/new",
-            "args"      => {
-                "user" => 1,
-                "text" => 1,
-            },
-        },
-        "destroy_direct_message" => {
-            "blankargs" => 0,
-            "post"      => 1,
-            "uri"       => "/direct_messages/destroy/ID",
-            "args"      => { "id" => 1, },
-        },
-        "create_friend" => {
-            "blankargs" => 0,
-            "post"      => 1,
-            "uri"       => "/friendships/create/ID",
-            "args"      => {
-                "id"     => 1,
-                "follow" => 0,
-            },
-        },
-        "destroy_friend" => {
-            "blankargs" => 0,
-            "post"      => 1,
-            "uri"       => "/friendships/destroy/ID",
-            "args"      => { "id" => 1, },
-        },
-        "relationship_exists" => {
-            "blankargs" => 0,
-            "post"      => 0,
-            "uri"       => "/friendships/exists",
-            "args"      => {
-                "user_a" => 1,
-                "user_b" => 1,
-            },
-        },
-        "verify_credentials" => {
-            "blankargs" => 1,
-            "post"      => 0,
-            "uri"       => "/account/verify_credentials",
-            "args"      => {},
-        },
-        "end_session" => {
-            "blankargs" => 1,
-            "post"      => 1,
-            "uri"       => "/account/end_session",
-            "args"      => {},
-        },
-        "update_profile_colors" => {
-            "blankargs" => 0,
-            "post"      => 1,
-            "uri"       => "/account/update_profile_colors",
-            "args"      => {
-                "profile_background_color"     => 0,
-                "profile_text_color"           => 0,
-                "profile_link_color"           => 0,
-                "profile_sidebar_fill_color"   => 0,
-                "profile_sidebar_border_color" => 0,
-            },
-        },
-        "update_profile_image" => {
-            "blankargs" => 0,
-            "post"      => 1,
-            "uri"       => "/account/update_profile_image",
-            "args"      => { "image" => 1, },
-        },
-        "update_profile_background_image" => {
-            "blankargs" => 0,
-            "post"      => 1,
-            "uri"       => "/account/update_profile_background_image",
-            "args"      => { "image" => 1, },
-        },
-        "update_delivery_device" => {
-            "blankargs" => 0,
-            "post"      => 1,
-            "uri"       => "/account/update_delivery_device",
-            "args"      => { "device" => 1, },
-        },
-        "rate_limit_status" => {
-            "blankargs" => 1,
-            "post"      => 0,
-            "uri"       => "/account/rate_limit_status",
-            "args"      => {},
-        },
-        "favorites" => {
-            "blankargs" => 1,
-            "post"      => 0,
-            "uri"       => "/favorites",
-            "args"      => {
-                "id"   => 0,
-                "page" => 0,
-            },
-        },
-        "create_favorite" => {
-            "blankargs" => 0,
-            "post"      => 1,
-            "uri"       => "/favorites/create/ID",
-            "args"      => { "id" => 1, },
-        },
-        "destroy_favorite" => {
-            "blankargs" => 0,
-            "post"      => 1,
-            "uri"       => "/favorites/destroy/ID",
-            "args"      => { "id" => 1, },
-        },
-        "enable_notifications" => {
-            "blankargs" => 0,
-            "post"      => 1,
-            "uri"       => "/notifications/follow/ID",
-            "args"      => { "id" => 1, },
-        },
-        "disable_notifications" => {
-            "blankargs" => 0,
-            "post"      => 1,
-            "uri"       => "/notifications/leave/ID",
-            "args"      => { "id" => 1, },
-        },
-        "create_block" => {
-            "blankargs" => 0,
-            "post"      => 1,
-            "uri"       => "/blocks/create/ID",
-            "args"      => { "id" => 1, },
-        },
-        "destroy_block" => {
-            "blankargs" => 0,
-            "post"      => 1,
-            "uri"       => "/blocks/destroy/ID",
-            "args"      => { "id" => 1, },
-        },
-        "test" => {
-            "blankargs" => 1,
-            "post"      => 0,
-            "uri"       => "/help/test",
-            "args"      => {},
-        },
-        "downtime_schedule" => {
-            "blankargs" => 100,
-            "post"      => 0,
-            "uri"       => "/help/downtime_schedule",
-            "args"      => {},
-        },
-    );
 
 ### Have to turn strict refs off in order to insert subrefs by value.
     no strict "refs";
 
+    *{_get_apicalls} = sub {
+        my $api = {
+            "public_timeline" => {
+                "blankargs" => 1,
+                "post"      => 0,
+                "uri"       => "/statuses/public_timeline",
+                "args"      => {},
+            },
+            "friends_timeline" => {
+                "blankargs" => 1,
+                "post"      => 0,
+                "uri"       => "/statuses/friends_timeline",
+                "args"      => {
+                    "since"    => 0,
+                    "since_id" => 0,
+                    "count"    => 0,
+                    "page"     => 0,
+                },
+            },
+            "user_timeline" => {
+                "blankargs" => 1,
+                "post"      => 0,
+                "uri"       => "/statuses/user_timeline/ID",
+                "args"      => {
+                    "id"       => 0,
+                    "since"    => 0,
+                    "since_id" => 0,
+                    "count"    => 0,
+                    "page"     => 0,
+                },
+            },
+            "show_status" => {
+                "blankargs" => 0,
+                "post"      => 0,
+                "uri"       => "/statuses/show/ID",
+                "args"      => { "id" => 1, },
+            },
+            "update" => {
+                "blankargs" => 0,
+                "post"      => 1,
+                "uri"       => "/statuses/update",
+                "args"      => {
+                    "status"                => 1,
+                    "in_reply_to_status_id" => 0,
+                    "source"                => 0,
+                },
+            },
+            "replies" => {
+                "blankargs" => 1,
+                "post"      => 0,
+                "uri"       => "/statuses/replies",
+                "args"      => {
+                    "page"     => 0,
+                    "since"    => 0,
+                    "since_id" => 0,
+                },
+            },
+            "destroy_status" => {
+                "blankargs" => 0,
+                "post"      => 1,
+                "uri"       => "/statuses/destroy/ID",
+                "args"      => { "id" => 1, },
+            },
+            "friends" => {
+                "blankargs" => 1,
+                "post"      => 0,
+                "uri"       => "/statuses/friends/ID",
+                "args"      => {
+                    "id"    => 0,
+                    "page"  => 0,
+                    "since" => 0,
+                },
+            },
+            "followers" => {
+                "blankargs" => 1,
+                "post"      => 0,
+                "uri"       => "/statuses/followers",
+                "args"      => {
+                    "id"   => 0,
+                    "page" => 0,
+                },
+            },
+            "show_user" => {
+                "blankargs" => 0,
+                "post"      => 0,
+                "uri"       => "/users/show/ID",
+                "args"      => {
+                    "id"    => 1,
+                    "email" => 1,
+                },
+            },
+            "direct_messages" => {
+                "blankargs" => 1,
+                "post"      => 0,
+                "uri"       => "/direct_messages",
+                "args"      => {
+                    "since"    => 0,
+                    "since_id" => 0,
+                    "page"     => 0,
+                },
+            },
+            "sent_direct_messages" => {
+                "blankargs" => 1,
+                "post"      => 0,
+                "uri"       => "/direct_messages/sent",
+                "args"      => {
+                    "since"    => 0,
+                    "since_id" => 0,
+                    "page"     => 0,
+                },
+            },
+            "new_direct_message" => {
+                "blankargs" => 0,
+                "post"      => 1,
+                "uri"       => "/direct_messages/new",
+                "args"      => {
+                    "user" => 1,
+                    "text" => 1,
+                },
+            },
+            "destroy_direct_message" => {
+                "blankargs" => 0,
+                "post"      => 1,
+                "uri"       => "/direct_messages/destroy/ID",
+                "args"      => { "id" => 1, },
+            },
+            "create_friend" => {
+                "blankargs" => 0,
+                "post"      => 1,
+                "uri"       => "/friendships/create/ID",
+                "args"      => {
+                    "id"     => 1,
+                    "follow" => 0,
+                },
+            },
+            "destroy_friend" => {
+                "blankargs" => 0,
+                "post"      => 1,
+                "uri"       => "/friendships/destroy/ID",
+                "args"      => { "id" => 1, },
+            },
+            "relationship_exists" => {
+                "blankargs" => 0,
+                "post"      => 0,
+                "uri"       => "/friendships/exists",
+                "args"      => {
+                    "user_a" => 1,
+                    "user_b" => 1,
+                },
+            },
+            "verify_credentials" => {
+                "blankargs" => 1,
+                "post"      => 0,
+                "uri"       => "/account/verify_credentials",
+                "args"      => {},
+            },
+            "end_session" => {
+                "blankargs" => 1,
+                "post"      => 1,
+                "uri"       => "/account/end_session",
+                "args"      => {},
+            },
+            "update_profile_colors" => {
+                "blankargs" => 0,
+                "post"      => 1,
+                "uri"       => "/account/update_profile_colors",
+                "args"      => {
+                    "profile_background_color"     => 0,
+                    "profile_text_color"           => 0,
+                    "profile_link_color"           => 0,
+                    "profile_sidebar_fill_color"   => 0,
+                    "profile_sidebar_border_color" => 0,
+                },
+            },
+            "update_profile_image" => {
+                "blankargs" => 0,
+                "post"      => 1,
+                "uri"       => "/account/update_profile_image",
+                "args"      => { "image" => 1, },
+            },
+            "update_profile_background_image" => {
+                "blankargs" => 0,
+                "post"      => 1,
+                "uri"       => "/account/update_profile_background_image",
+                "args"      => { "image" => 1, },
+            },
+            "update_delivery_device" => {
+                "blankargs" => 0,
+                "post"      => 1,
+                "uri"       => "/account/update_delivery_device",
+                "args"      => { "device" => 1, },
+            },
+            "rate_limit_status" => {
+                "blankargs" => 1,
+                "post"      => 0,
+                "uri"       => "/account/rate_limit_status",
+                "args"      => {},
+            },
+            "favorites" => {
+                "blankargs" => 1,
+                "post"      => 0,
+                "uri"       => "/favorites",
+                "args"      => {
+                    "id"   => 0,
+                    "page" => 0,
+                },
+            },
+            "create_favorite" => {
+                "blankargs" => 0,
+                "post"      => 1,
+                "uri"       => "/favorites/create/ID",
+                "args"      => { "id" => 1, },
+            },
+            "destroy_favorite" => {
+                "blankargs" => 0,
+                "post"      => 1,
+                "uri"       => "/favorites/destroy/ID",
+                "args"      => { "id" => 1, },
+            },
+            "enable_notifications" => {
+                "blankargs" => 0,
+                "post"      => 1,
+                "uri"       => "/notifications/follow/ID",
+                "args"      => { "id" => 1, },
+            },
+            "disable_notifications" => {
+                "blankargs" => 0,
+                "post"      => 1,
+                "uri"       => "/notifications/leave/ID",
+                "args"      => { "id" => 1, },
+            },
+            "create_block" => {
+                "blankargs" => 0,
+                "post"      => 1,
+                "uri"       => "/blocks/create/ID",
+                "args"      => { "id" => 1, },
+            },
+            "destroy_block" => {
+                "blankargs" => 0,
+                "post"      => 1,
+                "uri"       => "/blocks/destroy/ID",
+                "args"      => { "id" => 1, },
+            },
+            "test" => {
+                "blankargs" => 1,
+                "post"      => 0,
+                "uri"       => "/help/test",
+                "args"      => {},
+            },
+            "downtime_schedule" => {
+                "blankargs" => 100,
+                "post"      => 0,
+                "uri"       => "/help/downtime_schedule",
+                "args"      => {},
+            },
+        };
+    };
+
 ### For each method name in %apicalls insert a stub method to handle request.
+    my %apicalls = %{ _get_apicalls() };
 
     foreach my $methodname ( keys %apicalls ) {
 
@@ -553,7 +557,25 @@ BEGIN {
             ### For backwards compatibility we need to handle the user handing a single, scalar
             ### arg in, instead of a hashref. Since the methods that allowed this in 1.xx have
             ### different defaults, use a bit of logic to stick the value in the right place.
-
+            my %idsubs = map { $_ => 1 } qw (
+                create_block
+                destroy_block
+                friends
+                show_user
+                create_friend
+                destroy_friend
+                destroy_direct_message
+                show_status
+                create_favorite
+                destroy_favorite
+                destroy_status
+                disable_notifications
+                enable_notifications
+                favorites
+                followers
+                user_timeline
+                );
+            
             if ( ( !ref($args) ) && ( defined $args ) ) {
                 if ( $whoami eq "relationship_exists" ) {
                     my $user_b = shift;
@@ -562,10 +584,7 @@ BEGIN {
                     $args = { "status" => $args };
                 } elsif ( $whoami eq "replies" ) {
                     $args = { "page" => $args };
-                } elsif ( $whoami =~
-m/create_block|destroy_block|friends\b|show_user|create_friend|destroy_friend|destroy_direct_message|show_status/
-                  )
-                {
+                } elsif ( exists $idsubs{$whoami} ) {
                     $args = { "id" => $args };
                 } elsif ( $whoami =~ m/update_profile_image|update_profile_background_image/ ) {
                     $args = { "image" => $args };
@@ -597,7 +616,7 @@ m/create_block|destroy_block|friends\b|show_user|create_friend|destroy_friend|de
 
             ### Create the URL. If it ends in /ID it needs the id param substituted
             ### into the URL and not as an arg.
-            if ( (my $uri = $method_def->{uri}) =~ s|/ID|| ) {
+            if ( ( my $uri = $method_def->{uri} ) =~ s|/ID|| ) {
                 if ( defined $args->{id} ) {
                     $url .= $uri . "/" . delete( $args->{id} ) . ".json";
                     $seen_id++;
@@ -739,7 +758,7 @@ Net::Twitter - Perl interface to twitter.com
 
 =head1 VERSION
 
-This document describes Net::Twitter version 2.04
+This document describes Net::Twitter version 2.05
 
 =head1 SYNOPSIS
 
@@ -973,11 +992,17 @@ Returns status of a single tweet. The status' author will be returned inline.
  
 The argument is the ID or email address of the twitter user to pull, and is REQUIRED.
  
+This method can take the "id" argument passed to it either as a single string, or in a hashref with a key
+called "id".
+
 =item C<destroy_status($id)>
  
 Destroys the status specified by the required ID parameter. The
 authenticating user must be the author of the specified status.
- 
+
+This method can take the "id" argument passed to it either as a single string, or in a hashref with a key
+called "id".
+
 =item C<user_timeline(...)>
 
 This returns an arrayref to an array of hashrefs, containing the 20 (or more) posts from
@@ -1011,8 +1036,11 @@ OPTIONAL: Narrows the returned results to a certain number of statuses. This is
  
 OPTIONAL: Gets the 20 next most recent statuses from the authenticating user and that user's
 friends, eg "page=3".
- 
+
 =back
+
+This method can take the "id" argument passed to it either as a single string, or in a hashref with a key
+called "id". If passed as a string, no other args can be specified.
  
  
 =item C<public_timeline()>
@@ -1031,11 +1059,6 @@ Accepts an optional hashref as an argument:
  
 =over
  
-=item C<id>
- 
-OPTIONAL: User id or email address of a user other than the authenticated user,
-in order to retrieve that user's friends_timeline.
- 
 =item C<since>
  
 OPTIONAL: Narrows the returned results to just those statuses created after the
@@ -1112,6 +1135,9 @@ OPTIONAL: Gets the 100 next most recent friends, eg "page=3".
  
 =back
  
+This method can take the "id" argument passed to it either as a single string, or in a hashref with a key
+called "id". If passed as a string, no other args can be specified.
+
 =item C<followers()>
  
 his returns an arrayref to an array of hashrefs. Each hashref contains the information 
@@ -1131,15 +1157,18 @@ OPTIONAL: The ID or screen name of the user for whom to request a list of follow
 =item C<page>
  
 OPTIONAL: Retrieves the next 100 followers.
- 
+
 =back
+
+This method can take the "id" argument passed to it either as a single string, or in a hashref with a key
+called "id". If passed as a string, no other args can be specified.
  
 =item C<show_user()>
  
 Returns a hashref containing extended information of a single user.
  
 The argument is a hashref containing either the user's ID or email address. It is required
-to pass either one or the other:
+to pass either one or the other, but not both:
  
 =over
  
@@ -1158,6 +1187,10 @@ created, this method will include the location information for the user
 from twittervision.com, placing it inside the returned hashref under the
 key C<twittervision>.
  
+This method can take the "id" argument passed to it either as a single string, or in a hashref with a key
+called "id". If passed as a string, no other args can be specified.
+
+ 
 =back
  
 =head2 DIRECT MESSAGE METHODS
@@ -1234,7 +1267,10 @@ REQUIRED: Text of direct message.
  
 Destroys the direct message specified in the required ID parameter. The
 authenticating user must be the recipient of the specified direct message.
- 
+
+This method can take the "id" argument passed to it either as a single string, or in a hashref with a key
+called "id".
+
 =back
  
 =head2 FRIENDSHIP METHODS
@@ -1255,15 +1291,21 @@ REQUIRED. The ID or screen name of the user to befriend.
 =item C<follow>
  
 OPTIONAL. Enable notifications for the target user in addition to becoming friends.
- 
+
 =back
- 
+
+This method can take the "id" argument passed to it either as a single string, or in a hashref with a key
+called "id". If passed as a string, no other args can be specified.
+
 =item C<destroy_friend($id)>
  
 Discontinues friendship with the user specified in the ID parameter as the
 authenticating user. Returns a hashref containing the unfriended user's information 
 when successful.
 
+This method can take the "id" argument passed to it either as a single string, or in a hashref with a key
+called "id".
+
  
 =item C<relationship_exists($user_a, $user_b)>
  
@@ -1399,9 +1441,13 @@ statuses.
 =item C<page>
  
 OPTIONAL: Gets the 20 next most recent favorite statuses, eg "page=3".
- 
+
 =back
  
+This method can take the "id" argument passed to it either as a single string, or in a hashref with a key
+called "id". If passed as a string, no other args can be specified.
+
+ 
 =item C<create_favorite()>
  
 Sets the specified ID as a favorite for the authenticating user.
@@ -1411,10 +1457,13 @@ This takes a hashref as an argument:
 =over
     
 =item C<id>
-REQUIRED: The ID of the status to favorite.
- 
+
+REQUIRED: The ID of the status to favorite. 
+
 =back
- 
+
+This method can take the "id" argument passed to it either as a single string, or in a hashref with a key
+called "id".
  
 =item C<destroy_favorite()>
  
@@ -1426,8 +1475,11 @@ This takes a hashref as an argument:
     
 =item C<id>
 REQUIRED. The ID of the status to un-favorite.
- 
+
 =back
+
+This method can take the "id" argument passed to it either as a single string, or in a hashref with a key
+called "id".
  
 =back
  
@@ -1446,8 +1498,11 @@ This takes a hashref as an argument:
     
 =item C<id>
 REQUIRED: The ID or screen name of the user to receive notices from.
- 
+
 =back
+
+This method can take the "id" argument passed to it either as a single string, or in a hashref with a key
+called "id".
  
 =item C<disable_notifications()>
  
@@ -1463,6 +1518,9 @@ This takes a hashref as an argument:
 REQUIRED: The ID or screen name of the user to stop receiving notices from.
  
 =back
+
+This method can take the "id" argument passed to it either as a single string, or in a hashref with a key
+called "id".
  
 =back
  
@@ -1475,6 +1533,9 @@ REQUIRED: The ID or screen name of the user to stop receiving notices from.
 Blocks the user id passed as an argument from the authenticating user.
 Returns a hashref containing the user information for the blocked user when successful.
  
+This method can take the "id" argument passed to it either as a single string, or in a hashref with a key
+called "id".
+ 
 You can find more information about blocking at
 L<http://help.twitter.com/index.php?pg=kb.page&id=69>.
  
@@ -1483,6 +1544,9 @@ L<http://help.twitter.com/index.php?pg=kb.page&id=69>.
 Un-blocks the user id passed as an argument from the authenticating user.
 Returns a hashref containing the user information for the blocked user when successful.
 
+This method can take the "id" argument passed to it either as a single string, or in a hashref with a key
+called "id".
+
 =back
  
 =head2 SEARCH
